@@ -85,12 +85,12 @@ sub dataCleaner {
         /HASH/ && do {
             for my $key (keys %$data) {
                 my $value = $data->{$key};
-                if (ref $value){
-                    $self->dataCleaner($value);
-                }
-                elsif ($key =~ /$match/){
+                if ($key =~ /$match/){
                     $data->{$key} = 'xxx';
                 }
+                elsif (ref $value){
+                    $self->dataCleaner($value);
+                }
             }
         }
     }
@@ -111,7 +111,7 @@ sub logRpcCall {
         $self->dataCleaner($data);
         my $userId = eval { $self->user->loginName } // '*UNKNOWN*';
         my $remoteAddr = $self->tx->remote_address;
-        $self->log->info("[$userId|$remoteAddr] CALL $method(".encode_json($data).")");
+        $self->log->debug("[$userId|$remoteAddr] CALL $method(".encode_json($data).")");
     }
     else {
         $self->SUPER::logRpcCall(@_);
@@ -132,7 +132,7 @@ sub logRpcReturn {
         $self->dataCleaner($data);
         my $userId = eval { $self->user->loginName } // '*UNKNOWN*';
         my $remoteAddr = $self->tx->remote_address;
-        $self->log->info("[$userId|$remoteAddr] RETURN ".encode_json($data));
+        $self->log->debug("[$userId|$remoteAddr] RETURN ".encode_json($data).")");
     }
     else {
         $self->SUPER::logRpcReturn(@_);
